@@ -10,12 +10,18 @@ def pre_commit(session):
     session.run("pre-commit", "run", "-a")
 
 
-@nox.session(python=["3.5", "3.6", "3.7", "3.8"])
+@nox.session(python=["3.8", "3.9", "3.10"])
 def tests(session):
     """Run unit test over different python env with code coverage"""
     session.install("pytest", "pytest-cov", "-e", ".")
     session.run(
-        "py.test", "--cov=xrectsel", "--cov-report=xml", "--cov-branch", "--color=yes", "-s", "-v",
+        "py.test",
+        "--cov=xrectsel",
+        "--cov-report=xml",
+        "--cov-branch",
+        "--color=yes",
+        "-s",
+        "-v",
     )
 
 
